@@ -1,5 +1,5 @@
 package App::rshasum;
-$App::rshasum::VERSION = '0.6.3';
+$App::rshasum::VERSION = '0.6.4';
 use 5.016;
 use strict;
 use warnings;
@@ -66,11 +66,16 @@ sub run
         'digest=s'     => \$digest,
         'skip=s'       => \@skips,
         'start-path=s' => \$start_path,
-    ) or die "foo $!";
+    ) or die "Unknown flags $!";
     if ( not defined($digest) )
     {
         die "Please give a --digest=[digest] argument.";
     }
+    if (@ARGV)
+    {
+        die
+qq#Leftover arguments "@ARGV" in the command line. (Did you intend to use --start-path ?)#;
+    }
     return shift()->_worker(
         {
             digest     => $digest,
@@ -95,7 +100,7 @@ App::rshasum - recursive shasum.
 
 =head1 VERSION
 
-version 0.6.3
+version 0.6.4
 
 =head1 SYNOPSIS
 
